import { useAjax } from '@/Hook/useAjax';
import { getCorpWechatAllApi } from '@/services/adqV3/global';
import { getCorpUserDayListApi, GetCorpUserDayListProps } from '@/services/adqV3/monitorEWList';
import { Button, Card, DatePicker, Select, Table } from 'antd';
import React, { useEffect, useState } from 'react';
import moment from 'moment';
import { CorpUserDayListTableConfig } from './tableConfig';

/**
 * 客服号加粉数据
 * @returns 
 */
const AstraSupport: React.FC = () => {

    /*******************************************/
    const [corpWechatList, setCorpWechatList] = useState<{ label: string, value: string }[]>([]);
    const [queryParamsNew, setQueryParamsNew] = useState<GetCorpUserDayListProps>({ pageNum: 1, pageSize: 20 });

    const getCorpWechatAll = useAjax((params) => getCorpWechatAllApi(params))
    const getCorpUserDayList = useAjax((params) => getCorpUserDayListApi(params))
    /*******************************************/

    useEffect(() => {
        getCorpWechatAll.run({}).then((res) => {
            if (res && res.length > 0) {
                setCorpWechatList(res.map((item: { corpName: string; localCorpId: string; }) => ({ label: item.corpName, value: item.localCorpId })));
            }
        })
    }, [])

    useEffect(() => {
        getCorpUserDayList.run(queryParamsNew)
    }, [queryParamsNew])

    return <Card
        title={<div style={{ display: 'flex', gap: 8 }}>
            <DatePicker
                value={queryParamsNew?.day ? moment(queryParamsNew.day) : undefined}
                onChange={(_, dateString) => {
                    setQueryParamsNew({ ...queryParamsNew, day: dateString, pageNum: 1 })
                }}
            />
            <Select
                showSearch
                placeholder="请选择企业"
                filterOption={(input, option) =>
                    ((option?.label ?? '') as any).toLowerCase().includes(input.toLowerCase())
                }
                style={{ width: 140 }}
                allowClear
                value={queryParamsNew?.corpId}
                loading={getCorpWechatAll.loading}
                onChange={(e) => {
                    setQueryParamsNew({ ...queryParamsNew, corpId: e, pageNum: 1 })
                }}
                options={corpWechatList}
            />
            <Button type='primary' onClick={() => getCorpUserDayList.refresh()}>刷新</Button>
        </div>}
        headStyle={{ padding: '0 16px' }}
        bodyStyle={{ padding: 16 }}
    >
        <Table 
            dataSource={getCorpUserDayList?.data?.records} 
            columns={CorpUserDayListTableConfig()}
            size='small'
            bordered
            rowKey={'id'}
            loading={getCorpUserDayList.loading}
            scroll={{ x: 1200 }}
            pagination={{
                total: getCorpUserDayList.data?.total,
                defaultPageSize: 20,
                current: queryParamsNew.pageNum,
                pageSize: queryParamsNew.pageSize,
            }}
            onChange={(pagination) => {
                const { current, pageSize } = pagination
                setQueryParamsNew({ ...queryParamsNew, pageNum: current as number, pageSize: pageSize as number || 20 })
            }}
        />
    </Card>
};

export default React.memo(AstraSupport);